@@ -33,16 +33,33 @@ G_DECLARE_FINAL_TYPE (GrdSessionRdp,
                       GrdSession);
 
 GrdSessionRdp *grd_session_rdp_new (GrdRdpServer      *rdp_server,
-                                    GSocketConnection *connection);
+                                    GSocketConnection *connection,
+#ifdef HAVE_NVENC
+                                    GrdRdpNvenc       *rdp_nvenc,
+#endif /* HAVE_NVENC */
+                                    int                reserved);
 
-int grd_session_rdp_get_framebuffer_stride (GrdSessionRdp *session_rdp);
+void grd_session_rdp_notify_error (GrdSessionRdp *session_rdp,
+                                   uint32_t       error_info);
+
+void grd_session_rdp_notify_graphics_pipeline_reset (GrdSessionRdp *session_rdp);
+
+void grd_session_rdp_notify_graphics_pipeline_ready (GrdSessionRdp *session_rdp);
+
+int grd_session_rdp_get_stride_for_width (GrdSessionRdp *session_rdp,
+                                          int            width);
 
 void grd_session_rdp_resize_framebuffer (GrdSessionRdp *session_rdp,
                                          uint32_t       width,
                                          uint32_t       height);
 
 void grd_session_rdp_take_buffer (GrdSessionRdp *session_rdp,
-                                  void          *data);
+                                  void          *data,
+                                  uint16_t       width,
+                                  uint16_t       height);
+
+void grd_session_rdp_maybe_encode_pending_frame (GrdSessionRdp *session_rdp,
+                                                 GrdRdpSurface *rdp_surface);
 
 void grd_session_rdp_update_pointer (GrdSessionRdp *session_rdp,
                                      uint16_t       hotspot_x,
@@ -51,8 +68,6 @@ void grd_session_rdp_update_pointer (GrdSessionRdp *session_rdp,
                                      uint16_t       height,
                                      uint8_t       *data);
 
-void grd_session_rdp_move_pointer (GrdSessionRdp *session_rdp,
-                                   uint16_t       x,
-                                   uint16_t       y);
+void grd_session_rdp_hide_pointer (GrdSessionRdp *session_rdp);
 
 #endif /* GRD_SESSION_RDP_H */
